@@ -248,6 +248,16 @@ test_that("renv uses safe library paths on Windows", {
 
 })
 
+test_that("renv uses safe library path when needed", {
+
+  renv_tests_scope()
+
+  badlib <- file.path(getwd(), "Has'Single'Quote")
+  dir.create(badlib)
+  expect_false(renv_libpaths_safe(badlib) == badlib)
+
+})
+
 test_that("renv can install packages from Bitbucket", {
   skip_on_cran()
   renv_tests_scope()
